@@ -1,7 +1,11 @@
 from docutils import nodes
-from sphinx.environment import NoUri
 from sphinx.util.nodes import make_refnode
 
+try:
+    from sphinx.errors import NoUri  # Sphinx 3.0
+except ImportError:
+    from sphinx.environment import NoUri  # Sphinx < 3.0
+
 
 class Need_incoming(nodes.Inline, nodes.Element):
     pass
@@ -56,9 +60,9 @@ def process_need_incoming(app, doctree, fromdocname):
 
                     # If we have several links, we add an empty text between them
                     if index + 1 < len(links_back):
-                        node_link_container += nodes.Text(" ", " ")
+                        node_link_container += nodes.Text(", ", ", ")
 
-                except NoUri:
+                except Exception:
                     # Irf the given need id can not be found, we must pass here....
                     pass
 
