@@ -1,7 +1,12 @@
 from docutils import nodes
-from sphinx.environment import NoUri
 from sphinx.util.nodes import make_refnode
 import sphinx
+
+try:
+    from sphinx.errors import NoUri  # Sphinx 3.0
+except ImportError:
+    from sphinx.environment import NoUri  # Sphinx < 3.0
+
 from pkg_resources import parse_version
 sphinx_version = sphinx.__version__
 if parse_version(sphinx_version) >= parse_version("1.6"):
@@ -79,7 +84,7 @@ def process_need_outgoing(app, doctree, fromdocname):
 
                     # If we have several links, we add an empty text between them
                     if index + 1 < len(links):
-                        node_link_container += nodes.Text(" ", " ")
+                        node_link_container += nodes.Text(", ", ", ")
 
                 except NoUri:
                     # If the given need id can not be found, we must pass here....
